# package_name

Description. 
The package package_name is used to:
	- Div5: Resto da divisão por 5 igual a 2 ou 3
	
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install RestoDivisao
```

## Author
lucio

## License
[MIT](https://choosealicense.com/licenses/mit/)